@@ -227,7 +227,8 @@ def get_cause_data():
 def get_age_restriction_edge(age_restriction, end=False):
     id_map = {
         0.0: [2, None],
-        0.01: [3, 2],
+        0.01917808: [3, 2],
+        0.07671233: [388, 3],
         0.10: [388, 3],
         0.5: [389, 388],
         1.0: [238, 389],
@@ -293,7 +294,11 @@ def make_cause_restrictions(cause):
             ),
         ),
     )
-    if cause.cause_id in [367, 368, 369, 370, 374, 375, 376, 379, 741, 995]:
+    if cause.cause_id in [367, 368, 369, 370, 374, 375, 376, 379, 741, 995, 1160]:
+        # These causes have some estimates for age group 15, but have cause restrictions
+        # listed as age group 14, since GBD reports based on a "standard" set of age groups
+        # for certain maternal causes, but does the computation for a somewhat wider interval
+        # for consistency.
         restrictions = list(restrictions)
         restrictions[5] = ("yll_age_group_id_end", 15)
         restrictions[7] = ("yld_age_group_id_end", 15)
@@ -301,16 +306,43 @@ def make_cause_restrictions(cause):
 
 
 def get_all_risk_metadata():
-    risks = gbd.get_rei_metadata(RISK_SET_ID).sort_values("rei_id")
-    risks = risks[["rei_id", "level", "rei_name", "parent_id", "most_detailed"]].set_index(
-        "rei_id"
-    )
+    risks = gbd.get_rei_metadata(RISK_SET_ID, include_all_metadata=True).sort_values("rei_id")
+    risks = risks[
+        [
+            "rei_id",
+            "level",
+            "rei_name",
+            "parent_id",
+            "most_detailed",
+            "age_specific_exp",
+            "exposure_type",
+            "female",
+            "has_sev",
+            "inv_exp",
+            "lancet_label",
+            "lancet_label_short",
+            "male",
+            "rei_calculation_type",
+            "rr_scalar",
+            "rrmax_at_sequela_level",
+            "rrmax_from_parent_rei",
+            "tmred_dist",
+            "tmrel_lower",
+            "tmrel_upper",
+            "unit",
+            "yld",
+            "yld_age_group_id_end",
+            "yld_age_group_id_start",
+            "yll",
+            "yll_age_group_id_end",
+            "yll_age_group_id_start",
+        ]
+    ].set_index("rei_id")
     risks["rei_name"] = clean_entity_list(risks["rei_name"])
     risks = risks.join(gbd.get_paf_of_one().set_index("rei_id"))
     risks = risks.join(gbd.get_cause_risk_mapping().set_index("rei_id"))
     risks = risks.join(gbd.get_category_mapping().set_index("rei_id"))
     risks = risks.join(gbd.get_mediation_mapping().set_index("rei_id"))
-    risks = risks.join(gbd.get_risk_metadata().set_index("rei_id"))
     risks.rei_calculation_type = risks.rei_calculation_type.map(
         {
             "0": "aggregation",
@@ -347,13 +379,18 @@ def get_risk_data() -> list:
 
         if distribution in ["normal", "lognormal", "ensemble"]:
             levels = None
-            scalar = risk["rr_scalar"]
+            scalar = risk["rr_scalar"] if not pd.isnull(risk["rr_scalar"]) else None
             if pd.isnull(risk["tmred_dist"]):
                 tmred = (
                     ("distribution", "draws"),
                     ("min", None),
                     ("max", None),
-                    ("inverted", bool(int(risk["inv_exp"]))),
+                    (
+                        "inverted",
+                        bool(int(risk["inv_exp"]))
+                        if not pd.isnull(risk["inv_exp"])
+                        else False,
+                    ),
                 )
             else:
                 tmred = (
