@@ -1,9 +1,14 @@
-from typing import List, Tuple
-
 from .base_template_builder import gbd_record_attrs, modelable_entity_attrs
 from .data import get_etiology_data, get_etiology_list
 from .globals import ID_TYPES
-from .util import SPACING, TAB, make_import, make_module_docstring, make_record
+from .util import (
+    DOUBLE_SPACING,
+    SINGLE_SPACING,
+    TAB,
+    make_import,
+    make_module_docstring,
+    make_record,
+)
 
 IMPORTABLES_DEFINED = ("Etiology", "etiologies")
 
@@ -12,7 +17,7 @@ def get_base_types():
     etiology_attrs = [
         ("name", "str"),
         ("kind", "str"),
-        ("gbd_id", f"Union[{ID_TYPES.REI_ID}, None]"),
+        ("gbd_id", f"{ID_TYPES.REI_ID} | None"),
     ]
 
     return {
@@ -39,7 +44,7 @@ def make_etiology(name: str, rei_id: float) -> str:
     return out
 
 
-def make_etiologies(etiology_list: List[Tuple[str, float]]) -> str:
+def make_etiologies(etiology_list: list[tuple[str, float]]) -> str:
     out = "etiologies = Etiologies(\n"
     for name, rei_id in etiology_list:
         out += make_etiology(name, rei_id)
@@ -49,19 +54,18 @@ def make_etiologies(etiology_list: List[Tuple[str, float]]) -> str:
 
 def build_mapping_template() -> str:
     out = make_module_docstring("Mapping templates for GBD etiologies.", __file__)
-    out += make_import("typing", ("Union",)) + "\n"
+    out += make_import(".base_template", ("GbdRecord", "ModelableEntity"))
     out += make_import(".id", (ID_TYPES.REI_ID,))
-    out += make_import(".base_template", ("ModelableEntity", "GbdRecord"))
 
     for entity, info in get_base_types().items():
-        out += SPACING
+        out += DOUBLE_SPACING
         out += make_record(entity, **info)
     return out
 
 
 def build_mapping() -> str:
     out = make_module_docstring("Mapping of GBD etiologies.", __file__)
-    out += make_import(".id", (ID_TYPES.REI_ID,))
-    out += make_import(".etiology_template", ("Etiology", "Etiologies")) + SPACING
+    out += make_import(".etiology_template", ("Etiologies", "Etiology"))
+    out += make_import(".id", (ID_TYPES.REI_ID,)) + SINGLE_SPACING
     out += make_etiologies(get_etiology_data())
     return out
