@@ -1,11 +1,17 @@
-from typing import List
-
 from .base_template_builder import gbd_record_attrs, modelable_entity_attrs
 from .data import get_sequela_data, get_sequela_list
 from .globals import ID_TYPES
-from .util import SPACING, TAB, make_import, make_module_docstring, make_record, to_id
+from .util import (
+    DOUBLE_SPACING,
+    SINGLE_SPACING,
+    TAB,
+    make_import,
+    make_module_docstring,
+    make_record,
+    to_id,
+)
 
-IMPORTABLES_DEFINED = ("Sequela", "Healthstate", "sequelae")
+IMPORTABLES_DEFINED = ("Healthstate", "Sequela", "sequelae")
 
 
 def get_base_types():
@@ -59,7 +65,7 @@ def make_sequela(name: str, s_id: float, mei_id: float, hs_name: str, hs_id: flo
     return out
 
 
-def make_sequelae(sequela_list: List[str]) -> str:
+def make_sequelae(sequela_list: list[str]) -> str:
     out = "sequelae = Sequelae(**{\n"
     for (name, sid, mei_id, hs_name, hsid) in sequela_list:
         out += make_sequela(name, sid, mei_id, hs_name, hsid)
@@ -69,18 +75,21 @@ def make_sequelae(sequela_list: List[str]) -> str:
 
 def build_mapping_template() -> str:
     out = make_module_docstring("Mapping templates for GBD sequelae.", __file__)
-    out += make_import(".id", (ID_TYPES.S_ID, ID_TYPES.ME_ID, ID_TYPES.HS_ID))
-    out += make_import(".base_template", ("ModelableEntity", "GbdRecord"))
+    out += make_import(".base_template", ("GbdRecord", "ModelableEntity"))
+    out += make_import(".id", (ID_TYPES.HS_ID, ID_TYPES.ME_ID, ID_TYPES.S_ID))
 
     for entity, info in get_base_types().items():
-        out += SPACING
+        out += DOUBLE_SPACING
         out += make_record(entity, **info)
     return out
 
 
 def build_mapping() -> str:
     out = make_module_docstring("Mapping of GBD sequelae.", __file__)
-    out += make_import(".id", (ID_TYPES.S_ID, ID_TYPES.HS_ID, ID_TYPES.ME_ID))
-    out += make_import(".sequela_template", ("Healthstate", "Sequela", "Sequelae")) + SPACING
+    out += make_import(".id", (ID_TYPES.HS_ID, ID_TYPES.ME_ID, ID_TYPES.S_ID))
+    out += (
+        make_import(".sequela_template", ("Healthstate", "Sequela", "Sequelae"))
+        + SINGLE_SPACING
+    )
     out += make_sequelae(get_sequela_data())
     return out
